--[[
LuCI - Lua Configuration Interface for MeshCruzer
Copyright 2011 Kentaro Matsuyama <matsuyama@thinktube.com>

]]--
local uci  = require "luci.model.uci".cursor()
local wa   = require "luci.tools.webadmin"
local ttu  = require "luci.tools.ttutil"
local nw   = require "luci.tools.network"

m = Map("dhcrelay", translate("dhcrelay_agent"), translate("dhcrelay_desc"))

main = m:section(TypedSection, "dhcrelay", "")
main.anonymous = true

enabled = main:option(Flag, "enabled", translate("dhcrelay_enable"))
enabled.rmempty = false

ifaces = main:option(MultiValue, "interfaces", translate("dhcrelay_interfaces"),
	translate("dhcrelay_interfaces_desc"))
ifaces.rmempty = true
ifaces.widget = "checkbox"
wa.cbi_add_networks(ifaces)

server = main:option(Value, "server", translate("dhcrelay_server"),
	translate("dhcrelay_server_desc"))

linksel = main:option(ListValue, "link_selection", translate("dhcrelay_link_selection"),
	translate("dhcrelay_link_selection_desc"))
linksel.rmempty = true
linksel:value("", translate("dhcrelay_unused"))
wa.cbi_add_networks(linksel)

function enabled.write(self, section, value)
	ifaces.force_overwrite = true
	Flag.write(self, section, value)
end

function ifaces.write(self, section, value)
	local en = self.map.uci:get("dhcrelay", section, "enabled") or "0"
	local ifaces = {}

	if type(value) == "string" then
		ifaces = ttu.split(value, " ")
	end

	if en and en == "1" and value and #value > 0 then
		-- turn dhcp off of this interface in dnsmasq (/etc/config/dhcp)
		for _, i in ipairs(ifaces) do
			m.uci:foreach("dhcp", "dhcp",
				function(s)
					if s.interface == i then
						m.uci:set("dhcp", s['.name'], "ignore", 1)
					end
				end)
		end
		m:chain("dhcp")
		m.uci:save("dhcp")
	end
	MultiValue.write(self, section, value)
end

------------------------------- validater ------------------------------
function server.validate(self, value)
	if value and nw.isIPv4(value) then
		return value
	else
		self.err_message = translate("dhcrelay_ipaddr_err")
		return nil
	end
end

return m
