--[[
LuCI - Lua Configuration Interface

Copyright 2008 Steven Barth <steven@midlink.org>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

$Id$
]]--
arg[1] = arg[1] or ""
m = Map("firewall", translate("firewall_rule"), translate("firewall_rule_desc"))

s = m:section(NamedSection, arg[1], "rule", "")
s.anonymous = true
s.addremove = false

back = s:option(DummyValue, "_overview", translate("overview"))
back.value = ""
back.titleref = luci.dispatcher.build_url("admin", "network", "firewall", "rule")

name = s:option(Value, "_name", translate("name")..translate("cbi_optional"))
name.rmempty = true

jump = s:option(ListValue, "target", translate("firewall_rule_target"))
jump.rmempty = true
jump.default = "ACCEPT"
jump:value("REJECT", translate("fw_reject"))
jump:value("DROP", translate("fw_drop"))
jump:value("ACCEPT", translate("fw_accept"))

iface = s:option(ListValue, "src", translate("fw_src"))
iface.rmempty = true

oface = s:option(ListValue, "dest", translate("fw_dest"))
oface:value("", translate("any", "Any"))
oface.rmempty = true

luci.model.uci.cursor():foreach("firewall", "zone",
	function (section)
		iface:value(section.name)
		oface:value(section.name)
	end)

proto = s:option(Value, "proto", translate("protocol"))
--proto.optional = true
proto:value("all", translate("fw_all", "ALL"))
proto:value("tcpudp", "TCP+UDP")
proto:value("tcp", "TCP")
proto:value("udp", "UDP")
proto:value("icmp", "ICMP")
proto.combobox_manual = translate("manual", "- Manual -")

s:option(Value, "src_ip", translate("firewall_rule_srcip")).optional = true
s:option(Value, "dest_ip", translate("firewall_rule_destip")).optional = true
s:option(Value, "src_mac", translate("firewall_rule_srcmac")).optional = true

sport = s:option(Value, "src_port", translate("firewall_rule_srcport"))
sport:depends("proto", "tcp")
sport:depends("proto", "udp")
sport:depends("proto", "tcpudp")
sport.combobox_manual = translate("manual", "- Manual -")

dport = s:option(Value, "dest_port", translate("firewall_rule_destport"))
dport:depends("proto", "tcp")
dport:depends("proto", "udp")
dport:depends("proto", "tcpudp")
dport.combobox_manual = translate("manual", "- Manual -")

-- port definition
sport:value("1-65534", "ALL(1-65534)")
dport:value("1-65534", "ALL(1-65534)")
sport:value("20-21", "FTP(TCP:20-21)")
dport:value("20-21", "FTP(TCP:20-21)")
sport:value("22", "SSH(TCP_UDP:22)")
dport:value("22", "SSH(TCP_UDP:22)")
sport:value("23", "TELNET(TCP:23)")
dport:value("23", "TELNET(TCP:23)")
sport:value("25", "SMTP(TCP:25)")
dport:value("25", "SMTP(TCP:25)")
sport:value("53", "DNS(TCP_UDP:53)")
dport:value("53", "DNS(TCP_UDP:53)")
sport:value("67-68", "DHCP(UDP:67-68)")
dport:value("67-68", "DHCP(UDP:67-68)")
sport:value("69", "TFTP(UDP:69)")
dport:value("69", "TFTP(UDP:69)")
sport:value("80", "HTTP(TCP:80)")
dport:value("80", "HTTP(TCP:80)")
sport:value("110", "POP3(TCP:110)")
dport:value("110", "POP3(TCP:110)")
sport:value("123", "NTP(UDP:123)")
dport:value("123", "NTP(UDP:123)")
sport:value("137-139", "NetBIOS(TCP_UDP:137-139)")
dport:value("137-139", "NetBIOS(TCP_UDP:137-139)")
sport:value("443", "HTTPS(TCP:443)")
dport:value("443", "HTTPS(TCP:443)")
sport:value("1723", "PPTP(TCP:1723)")
dport:value("1723", "PPTP(TCP:1723)")

return m
