--[[
LuCI interface for vrec
Copyright (C) 2010-2011 Thinktube Inc
]]--
local util = require "luci.util"
local nw   = require "luci.tools.network"

m = Map("vrec", translate("vrec_index", "Video Recording"), translate("vrec_description", "Video Recording For Panasonic IP cameras"))

---- camera ----
camera = m:section(TypedSection, "camera", translate("vrec_section_camera", "Camera"))
camera.addremove = true

enabled = camera:option(Flag, "enabled", translate("vrec_enable", "Enable Recording"))
enabled.rmempty = false

camModel = camera:option(ListValue, "camModel", translate("vrec_camModel", "Camera Model"))
camModel.rmempty = false

camFormat = camera:option(ListValue, "camFormat", translate("vrec_camFormat", "Video Format"))
camFormat.rmempty = false

camRes=camera:option(ListValue, ("camRes"), translate("vrec_camRes", "Video Resolution"))
camRes.rmempty = false

formats= { } -- image formats
resol= { } -- resxModelxFmt
fmts = { "mp4", "mjpeg", "raw", "default" }	-- for testing & initial development

-- inserts values for models, formats and resolutions
-- get_list() --> doesn't work (ver.0.10 only?)
-- http://luci.subsignal.org/api/luci/modules/luci.model.uci.html
m.uci:foreach("vrec", "model",
	function(s)
		--print("--vrec model debug 2")
		local currModel="none"
		for k,v in pairs(s) do
			--print("=============================== key =", k, "v=", v)
			if k == ".name" then
				camModel:value(v, v)
				currModel=v
			elseif k == "fmt" then
				for k2,v2 in pairs(v) do
					--print("currmodel=", currModel)
					local exists = formats[v2]
					if exists == nil then 
						--print ("inserting new format:", v2)
						formats[v2]=({currModel})
					else
						--print ("updating format with model:", currModel)
						table.insert(formats[v2], currModel)
					end
				end
			elseif k:sub(1,3) == "res" then 
				theformat=k:sub(5)
				for k2,v2 in pairs(v) do
					--print ("pairs A:", k2, v2)
					local exists = resol[v2]
					if exists == nil then 
						--print ("inserting new res:")
						resol[v2]=({currModel .. "|" ..theformat})
					else
						--print ("updating res:")
						table.insert(resol[v2], currModel .. "|" .. theformat)
					end
				end
			end
			
		end
	end)
--	
--for k,v in pairs(formats) do
--	print("formats(final)=", k, v)
--end

local function serializeFmt(t, cnt)	--returns Formats' model table as a list of return arguments
	if t==nil then
		return nil
	end
	local cnt = cnt or #t
	if cnt<=1 then
		return {camModel=t[1]}
	else
		return {camModel=t[cnt]}, serializeFmt(t, cnt-1)
	end
end
--processign formats...
for k,v in pairs(formats) do	-- inserts 
	camFormat:value(k, k, serializeFmt(formats[k]) )
end
local function split (str, sep)	-- splits str in two, split point where sep found
	local start=string.find(str, sep)
	local a=string.sub(str, 1, start-1)
	local b=string.sub(str, start+1)	
	return a, b	
end

local function serializeRes(t, cnt)	--returns Resolution's format table as a list of return arguments
	if t==nil then
		return nil
	end
	local cnt = cnt or #t
	if cnt==1 then
		local a, b = split(t[1], "|")
		return {camModel=a, camFormat=b}
	else
		local a, b = split(t[cnt], "|")
		return {camModel=a, camFormat=b}, serializeRes(t, cnt-1)
	end
end
--processign resolutions...
for k,v in pairs(resol) do	-- inserts 
	camRes:value(k, k, serializeRes(resol[k]) )
end

camFps = camera:option(Value, "camFps", translate("vrec_camFps", "Camera Frame Rate"))
camFps.optional = true

--[[ two controls as one element
timestamp = camera:option(Value, "time", "Time stamp")
timestamp.template = "vrec/vrec_timeval" -- view template name: vrec_timeval.htm
timestamp.formvalue = function(self, section) -- This will assemble the parts
	local hour = self.map:formvalue(self:cbid(section) .. ".hour")
	local min = self.map:formvalue(self:cbid(section) .. ".min")
	print("H:", hour, "M:", min)
	if hour and min and #hour > 0 and #min > 0 then
		return hour .. ":" .. min
	else
		return nil
	end
end
--]]


camip = camera:option(Value, "camIP", translate("vrec_camIP", "Camera IP address"))
camip.rmempty = false
user = camera:option(Value, "usr", translate("vrec_usr", "Camera User Name"))
user.rmempty = false
user.optional = true
passwd = camera:option(Value, "pwd", translate("vrec_pwd", "Camera Password"))
passwd.rmempty = false
passwd.password = true
passwd.optional = true

storage = camera:option(ListValue, "storage", translate("vrec_storage", "Storage medium"))
m.uci:foreach("fstab", "mount",
	function(s)
		if s.target and #s.target > 0 and s.enabled == "1" then
			storage:value(s.target)
		end
	end)
storage.optional = false
storage.rmempty = false
-- check https://forum.openwrt.org/viewtopic.php?pid=145226 for the uci hooks feature
-- mount points could be verified using luci.sys.mounts(), for instance:
-- require "luci.sys"
-- mounts = luci.sys.mounts()
-- for k,v in pairs(mounts) do for k2,v2 in pairs(v) do print(k2,v2) end end

filename = camera:option(Value, "filename", translate("vrec_filename", "Filename Prefix"), translate("vrec_seconds", "Add '/' to create subdirectories")))
filename.rmempty = false

recTime = camera:option(Value, "recTime", translate("vrec_recTime", "Recording time / hr"), translate("vrec_seconds", "value in seconds"))
recTime.rmempty = false


--param = m:section(TypedSection, "model", translate("vrec_section_param", "Models"))
--res=param:option(DynamicList, ("res_mp4"), translate("vrec_paramRes", "Video Resolution mp4"))

------------------------------- validation ------------------------------
function validate_string(self, value, _max)
	local max_val = tonumber(_max)

	if not max_val then
		max_val = 64
	end
	if value and #value > 0 and #value < max_val then
		return value
	else
		self.err_message = translate("error_string", "Error")
		return nil
	end
end

function validate_value(self, value, _min, _max)
	local min_val = _min
	local max_val = _max
	local v = tonumber(value)

	if not min_val then
		min_val = 0
	end
	if not max_val then
		max_val = 65535
	end
	if v and v >= min_val and v <= max_val then
		return value
	else
		self.err_message = translate("error_value", "Error") ..
				" (" .. translate("min") .. " " .. tostring(min_val) .. ", " ..
				translate("max") .. " " .. tostring(max_val) .. ")"
		return nil
	end
end

function validate_ip(self, value)
	if value and nw.isIPv4(value) then
		return value
	else
		self.err_message = translate("error_ip", "Error in IP Address")
		return nil
	end
end

function validate_storage(self, value)
	if value then
		return value
	else
		self.err_message = translate("error_storage", "Error in Storage")
		return nil
	end
end

function validate_fps(self, value)
	return validate_value(self, value, 1, 30)
end

-- camera
camFps.validate = validate_fps
camip.validate = validate_ip
user.validate = validate_string
passwd.validate = validate_string

storage.validate = validate_string
filename.validate = validate_string

----------------------------------------------------------------------

return m
